package com.ruoyi.kaohe.service;

import java.util.List;
import com.ruoyi.kaohe.domain.KhTemItem;

/**
 * 模板考核项关联Service接口
 * 
 * @author hs
 * @date 2025-06-17
 */
public interface IKhTemItemService 
{
    /**
     * 查询模板考核项关联
     * 
     * @param id 模板考核项关联主键
     * @return 模板考核项关联
     */
    public KhTemItem selectKhTemItemById(Long id);

    /**
     * 查询模板考核项关联列表
     * 
     * @param khTemItem 模板考核项关联
     * @return 模板考核项关联集合
     */
    public List<KhTemItem> selectKhTemItemList(KhTemItem khTemItem);

    /**
     * 新增模板考核项关联
     * 
     * @param khTemItem 模板考核项关联
     * @return 结果
     */
    public int insertKhTemItem(KhTemItem khTemItem);

    /**
     * 修改模板考核项关联
     * 
     * @param khTemItem 模板考核项关联
     * @return 结果
     */
    public int updateKhTemItem(KhTemItem khTemItem);

    /**
     * 批量删除模板考核项关联
     * 
     * @param ids 需要删除的模板考核项关联主键集合
     * @return 结果
     */
    public int deleteKhTemItemByIds(Long[] ids);

    /**
     * 删除模板考核项关联信息
     * 
     * @param id 模板考核项关联主键
     * @return 结果
     */
    public int deleteKhTemItemById(Long id);
}
